@@ -1,14 +1,17 @@
 #!/usr/bin/python
 import os
 import sys
+from typing import Sequence
 
 # __version__ import need to be first in order to avoid circular import within logger
 from ._version import __version__  # noqa
+
+# isort: split
 from flexget import log  # noqa
 from flexget.manager import Manager  # noqa
 
 
-def main(args=None):
+def main(args: Sequence = None):
     """Main entry point for Command Line Interface"""
 
     try:
@@ -58,7 +61,7 @@ def main(args=None):
         sys.exit(1)
 
 
-def _is_debug():
+def _is_debug() -> bool:
     return any(
         arg in ['debug', '--debug', '--loglevel=trace', '--loglevel=debug']
         for arg in [a.lower() for a in sys.argv]
