@@ -2,6 +2,8 @@ import datetime
 import os
 import re
 from collections import defaultdict
+from json import JSONDecodeError
+from json import loads as json_loads
 from typing import Any, Callable, Dict, List, Match, Optional, Pattern, Union
 from urllib.parse import parse_qsl, urlparse
 
@@ -310,6 +312,19 @@ def is_valid_template(instance) -> bool:
     return get_template(instance) is not None
 
 
+@format_checker.checks('json', raises=ValueError)
+def is_json(instance) -> bool:
+    if not isinstance(instance, str):
+        return False
+
+    try:
+        decoded_json = json_loads(instance)
+    except JSONDecodeError as e:
+        raise ValueError('`%s` is not a valid json' % instance)
+
+    return True
+
+
 def set_error_message(error: jsonschema.ValidationError) -> None:
     """
     Create user facing error message from a :class:`jsonschema.ValidationError` `error`
