@@ -299,22 +299,20 @@ class Manager:
                 logger.error('Reloading config failed: {}', e)
         # Handle --tasks
         if options.tasks:
-            # Consider * the same as not specifying tasks at all (makes sure manual plugin still works)
+            # Consider '*' the same as not specifying any tasks.
+            # (So manual plugin doesn't consider them explicitly enabled.)
             if options.tasks == ['*']:
                 options.tasks = None
             else:
-                # Create list of tasks to run, preserving order
                 task_names = []
-                for arg in options.tasks:
-                    matches = [
-                        t for t in self.tasks if fnmatch.fnmatchcase(str(t).lower(), arg.lower())
-                    ]
-                    if not matches:
-                        msg = f'`{arg}` does not match any tasks'
-                        logger.error(msg)
+                for task in options.tasks:
+                    try:
+                        task_names.extend(
+                            m for m in self.matching_tasks(task) if m not in task_names
+                        )
+                    except ValueError as e:
+                        logger.error(e)
                         continue
-                    task_names.extend(m for m in matches if m not in task_names)
-                # Set the option as a list of matching task names so plugins can use it easily
                 options.tasks = task_names
         # TODO: 1.2 This is a hack to make task priorities work still, not sure if it's the best one
         task_names = sorted(
@@ -1052,6 +1050,14 @@ class Manager:
         global manager
         manager = None
 
+    def matching_tasks(self, task: str) -> Optional[List[str]]:
+        """Create list of tasks to run, preserving order"""
+        task_names = [t for t in self.tasks if fnmatch.fnmatchcase(str(t).lower(), task.lower())]
+        if not task_names:
+            raise ValueError(f'`{task}` does not match any tasks')
+
+        return task_names
+
     def crash_report(self) -> str:
         """
         This should be called when handling an unexpected exception. Will create a new log file containing the last 50
