@@ -1,15 +1,13 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
 import codecs
-import logging
+
 import yaml
+from loguru import logger
 
 from flexget import options
 from flexget.event import event
 from flexget.terminal import console
 
-log = logging.getLogger('check')
+logger = logger.bind(name='check')
 
 
 @event('manager.before_config_load')
@@ -46,7 +44,7 @@ def pre_check_config(config_path):
 
     for line in config.splitlines():
         if '# warnings off' in line.strip().lower():
-            log.debug('config pre-check warnings off')
+            logger.debug('config pre-check warnings off')
             break
         line_num += 1
         # remove linefeed
@@ -84,27 +82,35 @@ def pre_check_config(config_path):
                 #        (indentation, prev_indentation, prev_mapping, prev_list, cur_list)
 
         if ':\t' in line:
-            log.critical('Line %s has TAB character after : character. '
-                         'DO NOT use tab key when editing config!' % line_num)
+            logger.critical(
+                'Line {} has TAB character after : character. DO NOT use tab key when editing config!',
+                line_num,
+            )
         elif '\t' in line:
-            log.warning('Line %s has tabs, use only spaces!' % line_num)
+            logger.warning('Line {} has tabs, use only spaces!', line_num)
         if isodd(indentation):
-            log.warning('Config line %s has odd (uneven) indentation' % line_num)
+            logger.warning('Config line {} has odd (uneven) indentation', line_num)
         if indentation > prev_indentation and not prev_mapping:
             # line increases indentation, but previous didn't start mapping
-            log.warning('Config line %s is likely missing \':\' at the end' % (line_num - 1))
+            logger.warning("Config line {} is likely missing ':' at the end", line_num - 1)
         if indentation > prev_indentation + 2 and prev_mapping and not prev_list:
             # mapping value after non list indented more than 2
-            log.warning('Config line %s is indented too much' % line_num)
+            logger.warning('Config line {} is indented too much', line_num)
         if indentation <= prev_indentation + (2 * (not cur_list)) and prev_mapping and prev_list:
-            log.warning('Config line %s is not indented enough' % line_num)
+            logger.warning('Config line {} is not indented enough', line_num)
         if prev_mapping and cur_list:
             # list after opening mapping
-            if indentation < prev_indentation or indentation > prev_indentation + 2 + (2 * prev_list):
-                log.warning('Config line %s containing list element is indented incorrectly' % line_num)
+            if indentation < prev_indentation or indentation > prev_indentation + 2 + (
+                2 * prev_list
+            ):
+                logger.warning(
+                    'Config line {} containing list element is indented incorrectly', line_num
+                )
         elif prev_mapping and indentation <= prev_indentation:
             # after opening a map, indentation doesn't increase
-            log.warning('Config line %s is indented incorrectly (previous line ends with \':\')' % line_num)
+            logger.warning(
+                "Config line {} is indented incorrectly (previous line ends with ':')", line_num
+            )
 
         # notify if user is trying to set same key multiple times in a task (a common mistake)
         for level in duplicates.keys():
@@ -115,8 +121,12 @@ def pre_check_config(config_path):
             name = line.split(':', 1)[0].strip()
             ns = duplicates.setdefault(indentation, {})
             if name in ns:
-                log.warning('Trying to set value for `%s` in line %s, but it is already defined in line %s!' %
-                            (name, line_num, ns[name]))
+                logger.warning(
+                    'Trying to set value for `{}` in line {}, but it is already defined in line {}!',
+                    name,
+                    line_num,
+                    ns[name],
+                )
             ns[name] = line_num
 
         prev_indentation = indentation
@@ -130,19 +140,19 @@ def pre_check_config(config_path):
             # as duplicates are not always wrong in a list. see #697
             duplicates[indentation] = {}
 
-    log.verbose('Pre-checked %s configuration lines' % line_num)
+    logger.verbose('Pre-checked {} configuration lines', line_num)
 
 
 def check(manager, options):
-    log.verbose('Checking config file `%s`' % manager.config_path)
+    logger.verbose('Checking config file `{}`', manager.config_path)
     if manager.is_daemon:
         # If we are running in a daemon, check disk config
         pre_check_config(manager.config_path)
         with codecs.open(manager.config_path, 'r', encoding='utf-8') as config_file:
             try:
-                config = yaml.load(config_file)
+                config = yaml.safe_load(config_file)
             except yaml.error.YAMLError as e:
-                log.critical('Config file is invalid YAML:')
+                logger.critical('Config file is invalid YAML:')
                 for line in str(e).split('\n'):
                     console(line)
                 return
@@ -150,12 +160,12 @@ def check(manager, options):
                 manager.validate_config(config)
             except ValueError as e:
                 for error in getattr(e, 'errors', []):
-                    log.critical("[%s] %s", error.json_pointer, error.message)
+                    logger.critical('[{}] {}', error.json_pointer, error.message)
             else:
-                log.verbose('Config passed check.')
+                logger.verbose('Config passed check.')
     else:
         # If we aren't in a daemon, the config already validated if we got here
-        log.verbose('Config passed check.')
+        logger.verbose('Config passed check.')
 
 
 @event('options.register')
