@@ -1,15 +1,13 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
-import logging
 import sys
 
+from loguru import logger
+
 from flexget import options
 from flexget.event import event
-from flexget.terminal import console
 from flexget.plugin import plugins
+from flexget.terminal import console
 
-log = logging.getLogger('doc')
+logger = logger.bind(name='doc')
 
 
 def trim(docstring):
