@@ -1,16 +1,14 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
 import os
-import logging
 import sys
 
+from loguru import logger
+
 from flexget.event import event
 from flexget.utils.simple_persistence import SimplePersistence
 
 __author__ = 'paranoidi'
 
-log = logging.getLogger('welcome')
+logger = logger.bind(name='welcome')
 
 
 @event('manager.lock_acquired')
@@ -25,19 +23,21 @@ def welcome_message(manager):
 
     # check for old users, assume old user if db larger than 2 MB
     if count == 5 and os.stat(manager.db_filename).st_size / 1024 / 1024 >= 2:
-        log.debug('Looks like old user, skipping welcome message')
+        logger.debug('Looks like old user, skipping welcome message')
         persistence['count'] = 0
         return
 
     count -= 1
     scheduler = 'scheduler' if sys.platform.startswith('win') else 'crontab'
     if not count:
-        log.info('FlexGet has been successfully started from %s (--cron). '
-                 'I hope you have %s under control now. This message will not be repeated again.' %
-                 (scheduler, scheduler))
+        logger.info(
+            'FlexGet has been successfully started from {} (--cron). I hope you have {} under control now. This message will not be repeated again.',
+            scheduler,
+            scheduler,
+        )
     else:
-        log.info('%sFlexGet has been successfully started from %s (--cron). '
-                 'This message will be repeated %i times for your set up verification conveniences.' %
-                 ('Congratulations! ' if count == 4 else '',
-                  scheduler, count))
+        logger.info(
+            '%sFlexGet has been successfully started from %s (--cron). This message will be repeated %i times for your set up verification conveniences.'
+            % ('Congratulations! ' if count == 4 else '', scheduler, count)
+        )
     persistence['count'] = count
