@@ -1,17 +1,14 @@
 """Plugin for mocking task data."""
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
-import logging
+from loguru import logger
 
 from flexget import plugin
 from flexget.entry import Entry
 from flexget.event import event
 
-log = logging.getLogger('mock')
+logger = logger.bind(name='mock')
 
 
-class Mock(object):
+class Mock:
     """
     Allows adding mock input entries.
 
@@ -28,12 +25,9 @@ class Mock(object):
         'type': 'array',
         'items': {
             'type': 'object',
-            'properties': {
-                'title': {'type': 'string'},
-                'url': {'type': 'string'}
-            },
-            'required': ['title']
-        }
+            'properties': {'title': {'type': 'string'}, 'url': {'type': 'string'}},
+            'required': ['title'],
+        },
     }
 
     def on_task_input(self, task, config):
