@@ -1,20 +1,16 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-from past.builtins import basestring
+from loguru import logger
 
-import logging
-
-from flexget import plugin
+from flexget import entry, plugin
 from flexget.event import event
 from flexget.utils.log import log_once
 
 try:
-    from flexget.plugins.internal.api_rottentomatoes import lookup_movie, API_KEY
+    # NOTE: Importing other plugins is discouraged!
+    from flexget.plugins.internal import api_rottentomatoes as plugin_api_rottentomatoes
 except ImportError:
-    raise plugin.DependencyError(issued_by='rottentomatoes_lookup', missing='api_rottentomatoes',
-                                 message='rottentomatoes_lookup requires the `api_rottentomatoes` plugin')
+    raise plugin.DependencyError(issued_by=__name__, missing='api_rottentomatoes')
 
-log = logging.getLogger('rottentomatoes_lookup')
+logger = logger.bind(name='rottentomatoes_lookup')
 
 
 def get_rt_url(movie):
@@ -23,7 +19,7 @@ def get_rt_url(movie):
             return link.url
 
 
-class PluginRottenTomatoesLookup(object):
+class PluginRottenTomatoesLookup:
     """
     Retrieves Rotten Tomatoes information for entries.
 
@@ -39,8 +35,9 @@ class PluginRottenTomatoesLookup(object):
         'rt_mpaa_rating': 'mpaa_rating',
         'rt_runtime': 'runtime',
         'rt_critics_consensus': 'critics_consensus',
-        'rt_releases': lambda movie: dict((release.name, release.date) for
-                                          release in movie.release_dates),
+        'rt_releases': lambda movie: dict(
+            (release.name, release.date) for release in movie.release_dates
+        ),
         'rt_critics_rating': 'critics_rating',
         'rt_critics_score': 'critics_score',
         'rt_audience_rating': 'audience_rating',
@@ -51,33 +48,36 @@ class PluginRottenTomatoesLookup(object):
         'rt_actors': lambda movie: [actor.name for actor in movie.cast],
         'rt_directors': lambda movie: [director.name for director in movie.directors],
         'rt_studio': 'studio',
-        'rt_alternate_ids': lambda movie: dict((alt_id.name, alt_id.id)
-                                               for alt_id in movie.alternate_ids),
+        'rt_alternate_ids': lambda movie: dict(
+            (alt_id.name, alt_id.id) for alt_id in movie.alternate_ids
+        ),
         'rt_url': get_rt_url,
         # Generic fields filled by all movie lookup plugins:
         'movie_name': 'title',
-        'movie_year': 'year'}
+        'movie_year': 'year',
+    }
 
-    schema = {'oneOf': [
-        {'type': 'boolean'},
-        {'type': 'string', 'description': 'provide a custom api key'}
-    ]}
+    schema = {
+        'oneOf': [
+            {'type': 'boolean'},
+            {'type': 'string', 'description': 'provide a custom api key'},
+        ]
+    }
 
     def __init__(self):
         self.key = None
 
+    @entry.register_lazy_lookup('rottentomatoes_lookup')
     def lazy_loader(self, entry):
         """Does the lookup for this entry and populates the entry fields.
 
         :param entry: entry to perform lookup on
-        :param field: the field to be populated (others may be populated as well)
         :returns: the field value
-
         """
         try:
             self.lookup(entry, key=self.key)
         except plugin.PluginError as e:
-            log_once(e.value.capitalize(), logger=log)
+            log_once(e.value.capitalize(), logger=logger)
 
     def lookup(self, entry, search_allowed=True, key=None):
         """
@@ -89,13 +89,14 @@ class PluginRottenTomatoesLookup(object):
         :raises PluginError: Failure reason
         """
         if not key:
-            key = self.key or API_KEY
-        movie = lookup_movie(smart_match=entry['title'],
-                             rottentomatoes_id=entry.get('rt_id', eval_lazy=False),
-                             only_cached=(not search_allowed),
-                             api_key=key
-                             )
-        log.debug(u'Got movie: %s' % movie)
+            key = self.key or plugin_api_rottentomatoes.API_KEY
+        movie = plugin_api_rottentomatoes.lookup_movie(
+            smart_match=entry['title'],
+            rottentomatoes_id=entry.get('rt_id', eval_lazy=False),
+            only_cached=(not search_allowed),
+            api_key=key,
+        )
+        logger.debug('Got movie: {}', movie)
         entry.update_using_map(self.field_map, movie)
 
         if not entry.get('imdb_id', eval_lazy=False):
@@ -108,13 +109,13 @@ class PluginRottenTomatoesLookup(object):
         if not config:
             return
 
-        if isinstance(config, basestring):
+        if isinstance(config, str):
             self.key = config.lower()
         else:
             self.key = None
 
         for entry in task.entries:
-            entry.register_lazy_func(self.lazy_loader, self.field_map)
+            entry.add_lazy_fields(self.lazy_loader, self.field_map)
 
     @property
     def movie_identifier(self):
@@ -124,4 +125,9 @@ class PluginRottenTomatoesLookup(object):
 
 @event('plugin.register')
 def register_plugin():
-    plugin.register(PluginRottenTomatoesLookup, 'rottentomatoes_lookup', api_ver=2, interfaces=['task', 'movie_metainfo'])
+    plugin.register(
+        PluginRottenTomatoesLookup,
+        'rottentomatoes_lookup',
+        api_ver=2,
+        interfaces=['task', 'movie_metainfo'],
+    )
