@@ -1,15 +1,12 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
-import logging
+from loguru import logger
 
 from flexget import plugin
 from flexget.event import event
 
-log = logging.getLogger('metainfo_task')
+logger = logger.bind(name='metainfo_task')
 
 
-class MetainfoTask(object):
+class MetainfoTask:
     """
     Set 'task' field for entries.
     """
