@@ -1,20 +1,19 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
 import inspect
-import logging
 import time
 from threading import Lock
 
 import sqlalchemy
+from loguru import logger
 
 from flexget import options
 from flexget.event import event
 from flexget.manager import Session
 
-log = logging.getLogger('debug_db_sess')
+logger = logger.bind(name='debug_db_sess')
 
-open_transactions_lock = Lock()  # multiple threads may call events, be safe by getting lock when using
+open_transactions_lock = (
+    Lock()
+)  # multiple threads may call events, be safe by getting lock when using
 open_transactions = {}
 
 
@@ -28,7 +27,7 @@ def find_caller(stack):
         if module.__name__.startswith('sqlalchemy'):
             continue
         return (module.__name__,) + tuple(frame[2:4]) + (frame[4][0].strip(),)
-    log.warning('Transaction from unknown origin')
+    logger.warning('Transaction from unknown origin')
     return None, None, None, None
 
 
@@ -36,13 +35,21 @@ def after_begin(session, transaction, connection):
     caller_info = find_caller(inspect.stack()[1:])
     with open_transactions_lock:
         if any(info[1] is not connection.connection for info in open_transactions.values()):
-            log.warning('Sessions from 2 threads! Transaction 0x%08X opened %s Already open one(s): %s',
-                        id(transaction), caller_info, open_transactions)
+            logger.warning(
+                'Sessions from 2 threads! Transaction 0x{:08X} opened {} Already open one(s): {}',
+                id(transaction),
+                caller_info,
+                open_transactions,
+            )
         elif open_transactions:
-            log.debug('Transaction 0x%08X opened %s Already open one(s): %s',
-                      id(transaction), caller_info, open_transactions)
+            logger.debug(
+                'Transaction 0x{:08X} opened {} Already open one(s): {}',
+                id(transaction),
+                caller_info,
+                open_transactions,
+            )
         else:
-            log.debug('Transaction 0x%08X opened %s', id(transaction), caller_info)
+            logger.debug('Transaction 0x{:08X} opened {}', id(transaction), caller_info)
         # Store information about this transaction
         open_transactions[transaction] = (time.time(), connection.connection) + caller_info
 
@@ -59,8 +66,14 @@ def after_flush(session, flush_context):
                 _iterate_parents = session.transaction._iterate_self_and_parents
 
             tid = next(id(t) for t in _iterate_parents() if t in open_transactions)
-            log.debug('Transaction 0x%08X writing %s new: %s deleted: %s dirty: %s',
-                      tid, caller_info, tuple(session.new), tuple(session.deleted), tuple(session.dirty))
+            logger.debug(
+                'Transaction 0x{:08X} writing {} new: {} deleted: {} dirty: {}',
+                tid,
+                caller_info,
+                tuple(session.new),
+                tuple(session.deleted),
+                tuple(session.dirty),
+            )
 
 
 def after_end(session, transaction):
@@ -70,11 +83,15 @@ def after_end(session, transaction):
             # Transaction was created but a connection was never opened for it
             return
         open_time = time.time() - open_transactions[transaction][0]
-        msg = 'Transaction 0x%08X closed %s (open time %s)' % (id(transaction), caller_info, open_time)
+        msg = 'Transaction 0x%08X closed %s (open time %s)' % (
+            id(transaction),
+            caller_info,
+            open_time,
+        )
         if open_time > 2:
-            log.warning(msg)
+            logger.warning(msg)
         else:
-            log.debug(msg)
+            logger.debug(msg)
         del open_transactions[transaction]
 
 
@@ -88,5 +105,8 @@ def debug_warnings(manager):
 
 @event('options.register')
 def register_parser_arguments():
-    options.get_parser().add_argument('--debug-db-sessions', action='store_true',
-                                      help='debug session starts and ends, for finding problems with db locks')
+    options.get_parser().add_argument(
+        '--debug-db-sessions',
+        action='store_true',
+        help='debug session starts and ends, for finding problems with db locks',
+    )
