@@ -1,12 +1,9 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
 from flexget import plugin
 from flexget.event import event
 from flexget.utils import pathscrub
 
 
-class PathScrub(object):
+class PathScrub:
     """
     Plugin that will clear illegal characters from paths. Other plugins should use this if available when
     creating paths. User can specify what os if filenames must be compatible with an os other than current.
