@@ -1,19 +1,16 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
-import logging
+from loguru import logger
 
 from flexget import plugin
 from flexget.event import event
 
-log = logging.getLogger('priority')
+logger = logger.bind(name='priority')
 
 
 # TODO: 1.2 figure out replacement for this
 # Currently the manager reads this value directly out of the config when the 'execute' command is run, and this plugin
 # does nothing but make the config key valid.
 # In daemon mode, schedules should be made which run tasks in the proper order instead of using this.
-class TaskPriority(object):
+class TaskPriority:
     """Set task priorities"""
 
     schema = {'type': 'integer'}
