@@ -1,6 +1,4 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-import logging
+from loguru import logger
 
 from flexget import options, plugin
 from flexget.event import event
@@ -12,7 +10,7 @@ except ImportError:
     # this will leave the plugin unloaded
     raise plugin.DependencyError(issued_by='memusage', missing='ext lib `guppy`', silent=True)
 
-log = logging.getLogger('mem_usage')
+logger = logger.bind(name='mem_usage')
 
 """
 http://blog.mfabrik.com/2008/03/07/debugging-django-memory-leak-with-trackrefs-and-guppy/
@@ -49,7 +47,11 @@ def on_manager_shutdown(manager):
         return
 
     import resource
-    console('Resource Module memory usage: %s (kb)' % resource.getrusage(resource.RUSAGE_SELF).ru_maxrss)
+
+    console(
+        'Resource Module memory usage: %s (kb)'
+        % resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
+    )
     global heapy
     console('Heapy module calculating memory usage:')
     console(heapy.heap())
@@ -61,5 +63,10 @@ def on_manager_shutdown(manager):
 
 @event('options.register')
 def register_parser_arguments():
-    options.get_parser().add_argument('--mem-usage', action='store_true', dest='mem_usage', default=False,
-                                      help='display memory usage debug information')
+    options.get_parser().add_argument(
+        '--mem-usage',
+        action='store_true',
+        dest='mem_usage',
+        default=False,
+        help='display memory usage debug information',
+    )
