@@ -1,16 +1,15 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-from future.moves.xmlrpc.client import ServerProxy
-
-import re
 import difflib
 import os.path
-import logging
+import re
+from xmlrpc.client import ServerProxy
+
+from loguru import logger
 
 from flexget import plugin
 from flexget.event import event
 
-log = logging.getLogger('subtitles')
+logger = logger.bind(name='subtitles')
+
 
 # movie hash, won't work here though
 # http://trac.opensubtitles.org/projects/opensubtitles/wiki/HashSourceCodes#Python
@@ -19,7 +18,7 @@ log = logging.getLogger('subtitles')
 # http://trac.opensubtitles.org/projects/opensubtitles/wiki/XMLRPC
 
 
-class Subtitles(object):
+class Subtitles:
     """
     Fetch subtitles from opensubtitles.org
     """
@@ -30,9 +29,9 @@ class Subtitles(object):
             'languages': {'type': 'array', 'items': {'type': 'string'}, 'default': ['eng']},
             'min_sub_rating': {'type': 'number', 'default': 0.0},
             'match_limit': {'type': 'number', 'default': 0.8},
-            'output': {'type': 'string', 'format': 'path'}
+            'output': {'type': 'string', 'format': 'path'},
         },
-        'additionalProperties': False
+        'additionalProperties': False,
     }
 
     def prepare_config(self, config, task):
@@ -56,7 +55,7 @@ class Subtitles(object):
             s = ServerProxy("http://api.opensubtitles.org/xml-rpc")
             res = s.LogIn("", "", "en", "FlexGet")
         except Exception:
-            log.warning('Error connecting to opensubtitles.org')
+            logger.warning('Error connecting to opensubtitles.org')
             return
 
         if res['status'] != '200 OK':
@@ -69,13 +68,15 @@ class Subtitles(object):
         # configuration
         languages = config['languages']
         min_sub_rating = config['min_sub_rating']
-        match_limit = config['match_limit']  # no need to change this, but it should be configurable
+        match_limit = config[
+            'match_limit'
+        ]  # no need to change this, but it should be configurable
 
         # loop through the entries
         for entry in entries:
             imdbid = entry.get('imdb_id')
             if not imdbid:
-                log.debug('no match for %s' % entry['title'])
+                logger.debug('no match for {}', entry['title'])
                 continue
 
             query = []
@@ -92,8 +93,11 @@ class Subtitles(object):
             # filter bad subs
             subtitles = [x for x in subtitles if x['SubBad'] == '0']
             # some quality required (0.0 == not reviewed)
-            subtitles = [x for x in subtitles if
-                         float(x['SubRating']) >= min_sub_rating or float(x['SubRating']) == 0.0]
+            subtitles = [
+                x
+                for x in subtitles
+                if float(x['SubRating']) >= min_sub_rating or float(x['SubRating']) == 0.0
+            ]
 
             filtered_subs = []
 
@@ -120,11 +124,17 @@ class Subtitles(object):
 
             # download
             for sub in filtered_subs:
-                log.debug('SUBS FOUND: %s %s %s' %
-                          (sub['MovieReleaseName'], sub['SubRating'], sub['SubLanguageID']))
+                logger.debug(
+                    'SUBS FOUND: {} {} {}',
+                    sub['MovieReleaseName'],
+                    sub['SubRating'],
+                    sub['SubLanguageID'],
+                )
 
                 f = task.requests.get(sub['ZipDownloadLink'])
-                subfilename = re.match('^attachment; filename="(.*)"$', f.headers['content-disposition']).group(1)
+                subfilename = re.match(
+                    '^attachment; filename="(.*)"$', f.headers['content-disposition']
+                ).group(1)
                 outfile = os.path.join(config['output'], subfilename)
                 fp = open(outfile, 'w')
                 fp.write(f.raw)
