@@ -1,12 +1,9 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
+from flexget.components.variables.variables import Variables
 from flexget.manager import Session
-from flexget.plugins.modify.variables import Variables
 from flexget.utils import json
 
 
-class TestVariablesAPI(object):
+class TestVariablesAPI:
     config = 'tasks: {}'
 
     variables_dict = {'test_variable_db': True}
@@ -32,3 +29,12 @@ class TestVariablesAPI(object):
         rsp = api_client.get('/variables/')
         assert rsp.status_code == 200, 'Response code is %s' % rsp.status_code
         assert json.loads(rsp.get_data(as_text=True)) == self.variables_dict
+
+    def test_variables_patch(self, api_client):
+        data = {'a': 'b', 'c': 'd'}
+        api_client.json_put('/variables/', data=json.dumps(data))
+        new_data = {'a': [1, 2, 3], 'foo': 'bar'}
+
+        rsp = api_client.json_patch('/variables/', data=json.dumps(new_data))
+        assert rsp.status_code == 200, 'Response code is %s' % rsp.status_code
+        assert json.loads(rsp.get_data(as_text=True)) == {'a': [1, 2, 3], 'foo': 'bar', 'c': 'd'}
