@@ -1,5 +1,6 @@
 import hashlib
 import os
+from typing import Tuple
 
 import requests
 from loguru import logger
@@ -8,7 +9,13 @@ logger = logger.bind(name='utils.cache')
 
 
 # TODO refactor this to use lru_cache
-def cached_resource(url, base_dir, force=False, max_size=250, directory='cached_resources'):
+def cached_resource(
+    url: str,
+    base_dir: str,
+    force: bool = False,
+    max_size: int = 250,
+    directory: str = 'cached_resources',
+) -> Tuple[str, str]:
     """
     Caches a remote resource to local filesystem. Return a tuple of local file name and mime type, use primarily
     for API/WebUI.
@@ -25,7 +32,7 @@ def cached_resource(url, base_dir, force=False, max_size=250, directory='cached_
     directory = os.path.dirname(file_path)
 
     if not os.path.exists(file_path) or force:
-        logger.debug('caching {}', url)
+        logger.debug(f'caching {url}')
         response = requests.get(url)
         response.raise_for_status()
         mime_type = response.headers.get('content-type')
@@ -38,7 +45,7 @@ def cached_resource(url, base_dir, force=False, max_size=250, directory='cached_
         if not force:
             while size >= max_size:
                 logger.debug(
-                    'directory {} size is over the allowed limit of {}, trimming', size, max_size
+                    f'directory {size} size is over the allowed limit of {max_size}, trimming'
                 )
                 trim_dir(directory)
                 size = dir_size(directory) / (1024 * 1024.0)
@@ -48,7 +55,7 @@ def cached_resource(url, base_dir, force=False, max_size=250, directory='cached_
     return file_path, mime_type
 
 
-def dir_size(directory):
+def dir_size(directory: str) -> int:
     """
     Sums the size of all files in a given dir. Not recursive.
 
@@ -62,14 +69,14 @@ def dir_size(directory):
     return size
 
 
-def trim_dir(directory):
+def trim_dir(directory: str) -> None:
     """
     Removed the least accessed file on a given dir
 
     :param directory: Directory to check
     """
 
-    def access_time(f):
+    def access_time(f: str) -> float:
         return os.stat(os.path.join(directory, f)).st_atime
 
     files = sorted(os.listdir(directory), key=access_time)
