@@ -1,6 +1,7 @@
 """Logging utilities"""
 import hashlib
 from datetime import datetime, timedelta
+from typing import TYPE_CHECKING, Optional
 
 import loguru
 from loguru import logger
@@ -13,11 +14,15 @@ from flexget.utils.database import with_session
 from flexget.utils.sqlalchemy_utils import table_schema
 
 logger = logger.bind(name='util.log')
-Base = db_schema.versioned_base('log_once', 0)
+
+if TYPE_CHECKING:
+    Base = object
+else:
+    Base = db_schema.versioned_base('log_once', 0)
 
 
 @db_schema.upgrade('log_once')
-def upgrade(ver, session):
+def upgrade(ver: Optional[int], session: Session):
     if ver is None:
         logger.info('Adding index to md5sum column of log_once table.')
         table = table_schema('log_once', session)
@@ -35,15 +40,15 @@ class LogMessage(Base):
     md5sum = Column(String, unique=True)
     added = Column(DateTime, default=datetime.now())
 
-    def __init__(self, md5sum):
+    def __init__(self, md5sum: str) -> None:
         self.md5sum = md5sum
 
-    def __repr__(self):
-        return "<LogMessage('%s')>" % self.md5sum
+    def __repr__(self) -> str:
+        return f"<LogMessage('{self.md5sum}')>"
 
 
 @event('manager.db_cleanup')
-def purge(manager, session: Session):
+def purge(manager, session: Session) -> None:
     """Purge old messages from database"""
     old = datetime.now() - timedelta(days=365)
 
@@ -59,7 +64,7 @@ def log_once(
     once_level: str = 'INFO',
     suppressed_level: str = 'VERBOSE',
     session: Session = None,
-):
+) -> Optional[bool]:
     """
     Log message only once using given logger`. Returns False if suppressed logging.
     When suppressed, `suppressed_level` level is still logged.
@@ -70,7 +75,7 @@ def log_once(
     if not manager:
         logger.warning('DB not initialized. log_once will not work properly.')
         logger.log(once_level, message)
-        return
+        return None
 
     digest = hashlib.md5()
     digest.update(message.encode('latin1', 'replace'))  # ticket:250
@@ -83,6 +88,7 @@ def log_once(
 
     row = LogMessage(md5sum)
     session.add(row)
+    session.flush()
 
     logger.log(once_level, message)
     return True
